Learn R Programming

siera (version 0.5.5)

.read_ars_json_metadata: Read ARS metadata from JSON

Description

Internal helper that ingests ARS metadata stored as JSON and converts it into the harmonised list of tibbles used elsewhere in the package.

Usage

.read_ars_json_metadata(ARS_path)

Value

A list of metadata tables extracted from the JSON file, or `NULL` when required sections are missing.

Arguments

ARS_path

Path to the JSON ARS metadata file.